#!/bin/sh 
# This script waits for bluetooth connections and then
# starts GPSD on connect.
# It then monitors and checks when the connection is
# broken and restarts listening
#
# Requires: 
# sdptool - included with bluetooth, create serial port profile
# gpsd - linux gps daemon 
# rfcomm - bluetooth connections
# 
# Run this script manually or better via a service
#################### Some definitions to edit ################## 
DEVICE=/dev/rfcomm9
CHANNEL=3
GPSD=gpsd
RFCOMM=rfcomm
SDPTOOL=sdptool
RFCOMMPID=/tmp/rfcomm.pid 
THISPID=/tmp/sharegps.pid 
# This is command to stop the not needed gpsd service 
# If necessarily replace with your system command 
GPSDSTOP="systemctl stop gpsd" 

#############################
# Wait for RFCOMM connection
#############################
wait_for_connect(){
while [ -z "`$RFCOMM -i $DEVICE | grep connected`" ]; do
sleep 5
done
sleep 1
systemctl start bt-gpsd.socket
wait_for_close
}

#############################
# Wait for Connection closed
#   and restart
#############################
wait_for_close(){
while [ -n "`$RFCOMM -i $DEVICE | grep connected`" ]; do
sleep 5
done
systemctl stop bt-gpsd
systemctl stop bt-gpsd.socket
stop
start
}

###########
# Stop
###########
stop(){
# can't call systemctl from here or it will hang on shutdown
rfcomm release $DEVICE
kill -3 `cat $RFCOMMPID`
kill -9 `cat $RFCOMMPID`
} 

########
# Start
########
start(){
echo $$ > $THISPID

# Be sure, system gpsd service is not running 
$GPSDSTOP 

sleep 1

# Start rfcomm 
$RFCOMM watch $DEVICE $CHANNEL &
echo $! > $RFCOMMPID

wait_for_connect
} 

#######
# Main
#######
case $1 in
	start)
        $SDPTOOL add --channel=$CHANNEL SP 
        sleep 1
	start
	;;
	stop) 
        kill -3 `cat $THISPID`
	stop
	;;
	restart)
        systemctl stop bt-gpsd
        systemctl stop bt-gpsd.socket
	stop
	start
	;;
	*)
	echo "Usage start|stop|restart"
esac

